@@ -8,6 +8,7 @@
 """ Unit tests for ‘dput’ module. """
 
 import builtins
+import contextlib
 import doctest
 import hashlib
 import io
@@ -154,7 +155,7 @@ class checksum_test_ErrorTestCase(checksum_test_TestCase):
         sys.exit.assert_called_with(EXIT_STATUS_FAILURE)
 
 
-class verify_signature_TestCase(
+class verify_signature_BaseTestCase(
         testscenarios.WithScenarios,
         testtools.TestCase):
     """ Base for test cases for `verify_signature` function. """
@@ -223,7 +224,7 @@ class verify_signature_TestCase(
         self.test_args.update(extra_args)
 
 
-class verify_signature_DebugMessageTestCase(verify_signature_TestCase):
+class verify_signature_DebugMessageTestCase(verify_signature_BaseTestCase):
     """ Test cases for `verify_signature` debug messages. """
 
     scenarios = [
@@ -243,7 +244,7 @@ class verify_signature_DebugMessageTestCase(verify_signature_TestCase):
         self.assertIn(expected_output, sys.stdout.getvalue())
 
 
-class verify_signature_ChecksTestCase(verify_signature_TestCase):
+class verify_signature_ChecksTestCase(verify_signature_BaseTestCase):
     """ Test cases for `verify_signature` checks. """
 
     file_args_scenarios = [
@@ -443,7 +444,7 @@ class create_upload_file_TestCase(
         self.assertIn(expected_output, sys.stdout.getvalue())
 
     def test_opens_log_file_with_expected_mode_and_encoding(self):
-        """ Should open log file with expected write mode and text encoding. """
+        """ Should open log file with expected mode and text encoding. """
         dput.dput.create_upload_file(**self.test_args)
         builtins.open.assert_called_with(
                 self.upload_log_file_double.path, self.expected_open_mode,
@@ -982,10 +983,8 @@ class version_check_ConsoleEncodingTestCase(version_check_TestCase):
         subprocess_double.set_stdout_content(
                 "{arch}\n".format(arch=test_architecture))
         self.test_args['debug'] = True
-        try:
+        with contextlib.suppress(FakeSystemExit):
             dput.dput.version_check(**self.test_args)
-        except FakeSystemExit:
-            pass
         expected_output = textwrap.dedent("""\
                 D: detected architecture: '{arch}'
                 """).format(arch=test_architecture)
@@ -1025,10 +1024,8 @@ class version_check_ArchitectureMatchTestCase(version_check_TestCase):
         subprocess_double.set_stdout_content(
                 "{arch}\n".format(arch=test_architecture))
         self.test_args['debug'] = True
-        try:
+        with contextlib.suppress(FakeSystemExit):
             dput.dput.version_check(**self.test_args)
-        except FakeSystemExit:
-            pass
         expected_output = textwrap.dedent("""\
                 D: detected architecture: '{arch}'
                 """).format(arch=test_architecture)
@@ -1048,10 +1045,8 @@ class version_check_ArchitectureMatchTestCase(version_check_TestCase):
         for double in doubles:
             double.set_stderr_content(self.getUniqueString())
         self.test_args['debug'] = False
-        try:
+        with contextlib.suppress(FakeSystemExit):
             dput.dput.version_check(**self.test_args)
-        except FakeSystemExit:
-            pass
         message_snippet = " stderr output:"
         self.assertNotIn(message_snippet, sys.stdout.getvalue())
 
@@ -1061,10 +1056,8 @@ class version_check_ArchitectureMatchTestCase(version_check_TestCase):
         test_output = self.getUniqueString()
         subprocess_double.set_stderr_content(test_output)
         self.test_args['debug'] = True
-        try:
+        with contextlib.suppress(FakeSystemExit):
             dput.dput.version_check(**self.test_args)
-        except FakeSystemExit:
-            pass
         expected_output = textwrap.dedent("""\
                 D: dpkg-architecture stderr output: {output!r}
                 """).format(output=test_output)
@@ -1077,10 +1070,8 @@ class version_check_ArchitectureMatchTestCase(version_check_TestCase):
                 ("dpkg", "--field")):
             double.set_stderr_content(test_output)
         self.test_args['debug'] = True
-        try:
+        with contextlib.suppress(FakeSystemExit):
             dput.dput.version_check(**self.test_args)
-        except FakeSystemExit:
-            pass
         expected_output = textwrap.dedent("""\
                 D: dpkg stderr output: {output!r}
                 """).format(output=test_output)
@@ -1093,10 +1084,8 @@ class version_check_ArchitectureMatchTestCase(version_check_TestCase):
                 ("dpkg", "-s")):
             double.set_stderr_content(test_output)
         self.test_args['debug'] = True
-        try:
+        with contextlib.suppress(FakeSystemExit):
             dput.dput.version_check(**self.test_args)
-        except FakeSystemExit:
-            pass
         expected_output = textwrap.dedent("""\
                 D: dpkg stderr output: {output!r}
                 """).format(output=test_output)
@@ -1210,7 +1199,7 @@ class version_check_PackageNotInstalledTestCase(version_check_TestCase):
         sys.exit.assert_called_with(EXIT_STATUS_FAILURE)
 
 
-class check_upload_logfile_TestCase(
+class check_upload_logfile_BaseTestCase(
         testscenarios.WithScenarios,
         testtools.TestCase):
     """ Base for test cases for `check_upload_logfile` function. """
@@ -1251,7 +1240,6 @@ class check_upload_logfile_TestCase(
                 host=self.test_host,
                 fqdn=self.runtime_config_parser.get(self.test_host, 'fqdn'),
                 check_only=False,
-                run_lintian=False,
                 force_upload=False,
                 debug=False,
                 )
@@ -1279,7 +1267,7 @@ class check_upload_logfile_TestCase(
         self.upload_log_file_double = double
 
 
-class check_upload_logfile_SuccessTestCase(check_upload_logfile_TestCase):
+class check_upload_logfile_SuccessTestCase(check_upload_logfile_BaseTestCase):
     """ Success test cases for `check_upload_logfile` function. """
 
     scenarios = [
@@ -1321,14 +1309,12 @@ class check_upload_logfile_SuccessTestCase(check_upload_logfile_TestCase):
 
     def test_returns_expected_result(self):
         """ Should return expected result for the scenario. """
-        try:
+        with contextlib.suppress(FakeSystemExit):
             result = dput.dput.check_upload_logfile(**self.test_args)
-        except FakeSystemExit:
-            pass
         self.assertEqual(self.expected_result, result)
 
 
-class check_upload_logfile_ExitTestCase(check_upload_logfile_TestCase):
+class check_upload_logfile_ExitTestCase(check_upload_logfile_BaseTestCase):
     """ Exit test cases for `check_upload_logfile` function. """
 
     scenarios = [
@@ -1336,10 +1322,39 @@ class check_upload_logfile_ExitTestCase(check_upload_logfile_TestCase):
                 'config_method': "ftp",
                 'config_fqdn': "quux.example.com",
                 'log_content': "foo quux.example.com bar\n",
-                'expected_exit_status': 0,
+                'expected_exit_status': os.EX_OK,
                 }),
             ]
 
+    def test_emits_expected_result_message(self):
+        """ Should emit a message explaining the result of the check. """
+        with contextlib.suppress(FakeSystemExit):
+            dput.dput.check_upload_logfile(**self.test_args)
+        expected_stderr_output = textwrap.dedent("""\
+            Package has already been uploaded to {host} on {fqdn},
+            recorded in upload log file ‘{logfile_path}’.
+            Not attempting upload.
+            """).format(
+                host=self.test_host,
+                fqdn=self.config_fqdn,
+                logfile_path=self.upload_log_file_double.path,
+                )
+        self.assertIn(expected_stderr_output, sys.stderr.getvalue())
+
+    def test_emits_expected_suggestion_message(self):
+        """ Should emit a message suggesting how to override the check. """
+        with contextlib.suppress(FakeSystemExit):
+            dput.dput.check_upload_logfile(**self.test_args)
+        expected_stderr_output = textwrap.dedent("""\
+            To ignore this check and attempt upload anyway,
+            use the ‘--force’ option.
+            """).format(
+                host=self.test_host,
+                fqdn=self.config_fqdn,
+                logfile_path=self.upload_log_file_double.path,
+                )
+        self.assertIn(expected_stderr_output, sys.stderr.getvalue())
+
     def test_calls_sys_exit_with_expected_exit_status(self):
         """ Should call `sys.exit` with expected exit status. """
         with testtools.ExpectedException(FakeSystemExit):
@@ -1347,7 +1362,7 @@ class check_upload_logfile_ExitTestCase(check_upload_logfile_TestCase):
         sys.exit.assert_called_with(self.expected_exit_status)
 
 
-class check_upload_logfile_ErrorTestCase(check_upload_logfile_TestCase):
+class check_upload_logfile_ErrorTestCase(check_upload_logfile_BaseTestCase):
     """ Error test cases for `check_upload_logfile` function. """
 
     log_file_scenarios = [
@@ -1367,7 +1382,7 @@ class check_upload_logfile_ErrorTestCase(check_upload_logfile_TestCase):
         sys.exit.assert_called_with(self.expected_exit_status)
 
 
-# Copyright © 2015–2022 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2024 Ben Finney <bignose@debian.org>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
