@@ -10,15 +10,11 @@
 import collections
 import doctest
 import io
-import itertools
-import locale
-import os
 import subprocess
 import sys
 import textwrap
 import unittest.mock
 
-import pkg_resources
 import testscenarios
 import testtools
 import testtools.matchers
@@ -29,12 +25,18 @@ from .helper import (
         EXIT_STATUS_COMMAND_NOT_FOUND,
         EXIT_STATUS_FAILURE,
         EXIT_STATUS_SUCCESS,
+        PasswdEntry,
         SubprocessDouble,
+        make_fake_distribution,
+        make_unique_slug,
+        patch_importlib_metadata_distribution,
         patch_locale_getpreferredencoding,
+        patch_os_environ,
+        patch_os_getuid,
+        patch_pwd_getpwuid,
         patch_subprocess_check_call,
         patch_sys_argv,
         patch_system_interfaces,
-        patch_time_time,
         )
 
 
@@ -361,7 +363,7 @@ class make_text_stream_TestCase(
                 'fake_file_params': {
                     'type': io.TextIOWrapper,
                     'content': u"Lorem ipsum",
-                    'encoding': str("utf-8"),
+                    'encoding': "utf-8",
                     },
                 'expected_encoding': "utf-8",
                 'expected_content': u"Lorem ipsum",
@@ -726,18 +728,6 @@ class get_progname_TestCase(
         self.assertEqual(self.expected_progname, result)
 
 
-def patch_pkg_resources_get_distribution(testcase):
-    """ Patch `pkg_resources.get_distribution` for the test case. """
-    if not hasattr(testcase, 'fake_distribution'):
-        testcase.fake_distribution = unittest.mock.MagicMock(
-                pkg_resources.Distribution)
-    func_patcher = unittest.mock.patch.object(
-            pkg_resources, "get_distribution", autospec=True,
-            return_value=testcase.fake_distribution)
-    func_patcher.start()
-    testcase.addCleanup(func_patcher.stop)
-
-
 class get_distribution_version_TestCase(
         testscenarios.WithScenarios,
         testtools.TestCase):
@@ -745,8 +735,8 @@ class get_distribution_version_TestCase(
 
     scenarios = [
             ('simple', {
-                'fake_distribution': unittest.mock.MagicMock(
-                    project_name="lorem", version="42.23"),
+                'fake_distribution': make_fake_distribution(
+                    name="lorem", version="42.23"),
                 }),
             ]
 
@@ -754,7 +744,7 @@ class get_distribution_version_TestCase(
         """ Set up test fixtures. """
         super().setUp()
 
-        patch_pkg_resources_get_distribution(self)
+        patch_importlib_metadata_distribution(self)
 
     def test_returns_expected_result(self):
         """ Should return expected version for the distribution. """
@@ -807,7 +797,84 @@ class make_person_text_from_fields_TestCase(
         self.assertEqual(self.expected_result, result)
 
 
-# Copyright © 2015–2022 Ben Finney <bignose@debian.org>
+class get_username_from_system_TestCase(
+        testscenarios.WithScenarios,
+        testtools.TestCase):
+    """ Test cases for `get_username_from_system` function. """
+
+    scenarios = [
+            ('login-from-environ', {
+                'os_environ': {
+                    'USER': "username-from-environ",
+                    },
+                'os_getuid_return_value': 13,
+                'expected_username': "username-from-environ",
+                }),
+            ('login-from-pwd', {
+                'os_environ': {},
+                'os_getuid_return_value': 17,
+                'pwd_getpwuid_return_value': PasswdEntry(
+                    *(["username-from-pwd"] + [object()] * 6)),
+                'expected_uid': 17,
+                'expected_username': "username-from-pwd",
+                }),
+            ]
+
+    def setUp(self):
+        """ Set up test fixtures. """
+        super().setUp()
+        patch_system_interfaces(self)
+
+        patch_os_environ(self)
+        patch_os_getuid(self)
+        patch_pwd_getpwuid(self)
+
+        self.set_test_args()
+
+    def set_test_args(self):
+        """ Set the arguments for the test call to the function. """
+        self.test_args = dict(
+                debug=False,
+                )
+
+    def test_emits_debug_message_for_username(self):
+        """ Should emit a debug message for the username. """
+        self.test_args['debug'] = True
+        dputhelper.get_username_from_system(**self.test_args)
+        expected_output = textwrap.dedent("""\
+                D: Login: {username}
+                """).format(username=self.expected_username)
+        self.assertIn(expected_output, sys.stderr.getvalue())
+
+    def test_emits_debug_message_for_userid(self):
+        """ Should emit a debug message for the user ID. """
+        if not hasattr(self, 'expected_uid'):
+            self.skipTest("No UID generated for this scenario")
+        self.test_args['debug'] = True
+        dputhelper.get_username_from_system(**self.test_args)
+        expected_output = textwrap.dedent("""\
+                D: User-ID: {uid}
+                """).format(uid=self.expected_uid)
+        self.assertIn(expected_output, sys.stderr.getvalue())
+
+    def test_returns_expected_username(self):
+        """ Should return expected username value. """
+        result = dputhelper.get_username_from_system(**self.test_args)
+        self.assertEqual(self.expected_username, result)
+
+
+def patch_get_username_from_system(testcase):
+    """ Patch the `get_username_from_system` function for the `testcase`. """
+    if not hasattr(testcase, 'system_username'):
+        testcase.system_username = make_unique_slug(testcase)
+    func_patcher = unittest.mock.patch.object(
+            dputhelper, "get_username_from_system", autospec=True,
+            return_value=testcase.system_username)
+    func_patcher.start()
+    testcase.addCleanup(func_patcher.stop)
+
+
+# Copyright © 2015–2024 Ben Finney <bignose@debian.org>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
