@@ -303,7 +303,7 @@ class AuthHandlerHackAround_get_header_TestCase(testtools.TestCase):
         self.assertIsNone(result)
 
     def test_returns_specified_default_when_specified_field_not_found(self):
-        """ Should return `default` value when specified field is not found. """
+        """ Should return `default` value when specified field not found. """
         setup_authrequest(self)
         test_field_name = self.getUniqueString()
         test_default_value = self.getUniqueString()
@@ -463,24 +463,6 @@ class AuthHandlerHackAround_get_auth_headers_TestCase(
                 expected_response_headers,
                 )
 
-    def test_calls_basicauthhandler_error_with_expected_args(self):
-        """
-        Should call `HTTPDigestAuthHandler.http_error_401` with expected args.
-        """
-        self.test_authrequest.get_auth_headers()
-        mock_method = self.mock_handler_error_methods[
-                urllib.request.HTTPDigestAuthHandler]
-        expected_request = self.test_authrequest
-        expected_status_code = http.client.UNAUTHORIZED
-        expected_response_headers = self.test_authrequest.response_headers
-        mock_method.assert_called_with(
-                expected_request,
-                unittest.mock.ANY,
-                expected_status_code,
-                unittest.mock.ANY,
-                expected_response_headers,
-                )
-
     def test_returns_accumulated_header_fields(self):
         """ Should return accumulated header fields. """
         result = self.test_authrequest.get_auth_headers()
@@ -488,7 +470,7 @@ class AuthHandlerHackAround_get_auth_headers_TestCase(
         self.assertEqual(result, expected_header_fields)
 
 
-# Copyright © 2015–2022 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2024 Ben Finney <bignose@debian.org>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
